.. pail documentation master file, created by
   sphinx-quickstart on Sat May  4 03:26:35 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


.. include:: ../README.rst

Documentation (detailed)
========================

.. toctree::
   :maxdepth: 2

   intro
   deployment
   developers
   pail


.. include:: ../CREDITS.txt

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


License
=======

.. include:: ../COPYRIGHT.txt

.. include:: ../CHANGES.txt
